@@ -17,12 +17,17 @@ class VUMeter : public Fl_Group {
     float min_value, max_value;
     int channel_height;
     int width, height;
+    int peak_bar_width;
+    int vu_end_xpos;
     int x_origin, y_origin;
     int left_chan_y1, left_chan_y2;
     int right_chan_y1, right_chan_y2;
     int tick_distance_dB;
     int tick_distance_px;
     int num_of_ticks;
+    Fl_Color solid_red;
+    Fl_Color solid_green;
+    Fl_Color solid_yellow;
 
     Fl_Color bg_color;
 
