@@ -18,13 +18,21 @@
 
 enum {
     STREAM_TIME = 0,
-    REC_TIME,
-    SENT_DATA,
-    REC_DATA,
+    REC_TIME = 1,
+    SENT_DATA = 2,
+    REC_DATA = 3,
+    STREAM_STATE = 4,
 };
+
 enum {
     STREAM = 0,
-    RECORD,
+    RECORD = 1,
+};
+
+enum {
+    CB_CALLED_BY_USER = 0,
+    CB_CALLED_BY_CODE = 1,
+    CB_CALLED_BY_MIDI = 2,
 };
 
 class flgui;
@@ -71,7 +79,9 @@ void input_cfg_song_suffix_cb(void);
 void input_cfg_buffer_cb(bool print_message);
 void input_cfg_signal_cb(void);
 void input_cfg_silence_cb(void);
-void input_cfg_(void);
+void check_stream_signal_cb(void);
+void check_stream_silence_cb(void);
+void input_cfg_reconnect_delay_cb(void);
 void input_cfg_present_level_cb(void);
 void input_cfg_absent_level_cb(void);
 void choice_cfg_resample_mode_cb(void);
@@ -91,6 +101,7 @@ void button_add_srv_save_cb(void);
 void button_add_srv_show_pwd_cb(void);
 void radio_add_srv_shoutcast_cb(void);
 void radio_add_srv_icecast_cb(void);
+void radio_add_srv_webrtc_cb(void);
 void radio_add_srv_radioco_cb(void);
 void button_add_srv_revoke_cert_cb(void);
 void button_add_srv_get_stations_cb(void);
@@ -120,6 +131,8 @@ void choice_rec_codec_flac_cb(void);
 void button_rec_codec_settings_cb(void);
 void input_rec_signal_cb(void);
 void input_rec_silence_cb(void);
+void check_rec_signal_cb(void);
+void check_rec_silence_cb(void);
 
 void input_tls_cert_file_cb(void);
 void input_tls_cert_dir_cb(void);
@@ -146,17 +159,25 @@ void check_gui_lcd_auto_cb(void);
 void check_gui_start_minimized_cb(void);
 void check_gui_disable_gain_slider_cb(void);
 void check_gui_show_listeners_cb(void);
+void input_gui_listeners_update_rate_cb(void);
 void button_gui_bg_color_cb(void);
 void button_gui_text_color_cb(void);
+void button_gui_vu_low_color_cb(void);
+void button_gui_vu_mid_color_cb(void);
+void button_gui_vu_high_color_cb(void);
+void input_gui_vu_mid_range_start_cb(void);
+void input_gui_vu_high_range_start_cb(void);
 void choice_gui_language_cb(void);
 void radio_gui_vu_gradient_cb(void);
 void radio_gui_vu_solid_cb(void);
 void check_gui_always_show_vu_tabs_cb(void);
+void input_gui_window_title_cb(void);
 
-void slider_gain_cb(void);
+void slider_gain_cb(void *called_by);
 void vu_tabs_cb(void);
 
-void check_activate_eq_cb(void);
+void check_stream_eq_cb(void);
+void check_rec_eq_cb(void);
 void button_eq_reset_cb(void);
 void choice_eq_preset_cb(void);
 void slider_equalizer1_cb(double);
@@ -170,7 +191,8 @@ void slider_equalizer8_cb(double);
 void slider_equalizer9_cb(double);
 void slider_equalizer10_cb(double);
 
-void check_activate_drc_cb(void);
+void check_stream_drc_cb(void);
+void check_rec_drc_cb(void);
 void button_drc_reset_cb(void);
 void check_aggressive_mode_cb(void);
 void slider_threshold_cb(double);
@@ -179,16 +201,17 @@ void slider_attack_cb(double);
 void slider_release_cb(double);
 void slider_makeup_cb(double);
 
-void slider_mixer_primary_device_cb(double);
-void slider_mixer_secondary_device_cb(double);
-void slider_mixer_streaming_gain_cb(double);
-void slider_mixer_recording_gain_cb(double);
-void slider_mixer_master_gain_cb(double);
-void slider_mixer_cross_fader_cb(double);
+void slider_mixer_primary_device_cb(double val, void *called_by);
+void slider_mixer_secondary_device_cb(double val, void *called_by);
+void slider_mixer_streaming_gain_cb(double val, void *called_by);
+void slider_mixer_recording_gain_cb(double val, void *called_by);
+void slider_mixer_master_gain_cb(double val, void *called_by);
+void slider_mixer_cross_fader_cb(double val, void *called_by);
 void button_mixer_reset_cb(void);
 void button_mixer_mute_primary_device_cb(void);
 void button_mixer_mute_secondary_device_cb(void);
 
+void check_cfg_overwrite_existing_files_cb(void);
 void check_cfg_auto_start_rec_cb(void);
 void check_cfg_auto_stop_rec_cb(void);
 void check_cfg_rec_after_launch_cb(void);
@@ -206,6 +229,10 @@ void choice_cfg_app_cb(void);
 void radio_cfg_artist_title_cb(void);
 void radio_cfg_title_artist_cb(void);
 
+void input_cfg_song_url_cb(void);
+void input_cfg_url_update_song_interval_cb(void);
+void check_cfg_update_from_url_cb(void);
+
 void choice_cfg_song_delay_cb(void);
 
 void update_song(void *user_data);
@@ -217,6 +244,16 @@ void choice_stream_mp3_bitrate_mode_cb(void);
 void choice_stream_mp3_vbr_quality_cb(void);
 void choice_stream_mp3_vbr_min_bitrate_cb(void);
 void choice_stream_mp3_vbr_max_bitrate_cb(void);
+void check_stream_mp3_force_min_bitrate_cb(void);
+void choice_stream_mp3_resampling_freq_cb(void);
+void check_stream_mp3_activate_lowpass_freq_cb(void);
+void input_stream_mp3_lowpass_freq_cb(void);
+void check_stream_mp3_activate_lowpass_width_cb(void);
+void input_stream_mp3_lowpass_width_cb(void);
+void check_stream_mp3_activate_highpass_freq_cb(void);
+void input_stream_mp3_highpass_freq_cb(void);
+void check_stream_mp3_activate_highpass_width_cb(void);
+void input_stream_mp3_highpass_width_cb(void);
 
 void choice_stream_vorbis_bitrate_mode_cb(void);
 void choice_stream_vorbis_vbr_quality_cb(void);
@@ -241,6 +278,16 @@ void choice_rec_mp3_bitrate_mode_cb(void);
 void choice_rec_mp3_vbr_quality_cb(void);
 void choice_rec_mp3_vbr_min_bitrate_cb(void);
 void choice_rec_mp3_vbr_max_bitrate_cb(void);
+void check_rec_mp3_force_min_bitrate_cb(void);
+void choice_rec_mp3_resampling_freq_cb(void);
+void check_rec_mp3_activate_lowpass_freq_cb(void);
+void input_rec_mp3_lowpass_freq_cb(void);
+void check_rec_mp3_activate_lowpass_width_cb(void);
+void input_rec_mp3_lowpass_width_cb(void);
+void check_rec_mp3_activate_highpass_freq_cb(void);
+void input_rec_mp3_highpass_freq_cb(void);
+void check_rec_mp3_activate_highpass_width_cb(void);
+void input_rec_mp3_highpass_width_cb(void);
 
 void choice_rec_vorbis_bitrate_mode_cb(void);
 void choice_rec_vorbis_vbr_quality_cb(void);
@@ -263,4 +310,14 @@ void radio_rec_wav_bit_depth_16_cb(void);
 void radio_rec_wav_bit_depth_24_cb(void);
 void radio_rec_wav_bit_depth_32_cb(void);
 
+void choice_midi_dev_cb(void);
+void choice_midi_cc_mode_cb(void);
+void check_midi_soft_takeover_cb(void);
+void button_midi_rescan_devices_cb(void);
+void browser_midi_command_cb(void);
+void input_midi_msg_num_cb(void);
+void choice_midi_channel_cb(void);
+void button_midi_learn_cb(void);
+void check_midi_command_enable_cb(void);
+
 #endif
