@@ -815,6 +815,10 @@ void fill_cfg_widgets(void)
     fl_g->browser_midi_command->add(_("Cross fader"));
     fl_g->browser_midi_command->add(_("Mute/Unmute Primary Device"));
     fl_g->browser_midi_command->add(_("Mute/Unmute Secondary Device"));
+    fl_g->browser_midi_command->add(_("Start broadcasting"));
+    fl_g->browser_midi_command->add(_("Stop broadcasting"));
+    fl_g->browser_midi_command->add(_("Start recording"));
+    fl_g->browser_midi_command->add(_("Stop recording"));
     fl_g->browser_midi_command->select(1); // Select first line (Yes, the line counter starts with 1)
     fl_g->check_midi_command_enable->value(cfg.midi.commands[0].enabled);
     fl_g->choice_midi_channel->value(cfg.midi.commands[0].channel);
@@ -913,7 +917,7 @@ void update_channel_lists(void)
     }
 }
 
-void write_log(const char *message)
+void write_log(const char *message, const char *path)
 {
     int len;
     FILE *log_fd;
@@ -931,13 +935,15 @@ void write_log(const char *message)
     }
     */
 
+    const char *log_file = path != NULL ? path : cfg.main.log_file;
+
     pthread_mutex_lock(&write_log_mutex);
 
-    if ((cfg.main.log_file != NULL) && (strlen(cfg.main.log_file) > 0)) {
+    if ((log_file != NULL) && (strlen(log_file) > 0)) {
         current_time = time(NULL);
         current_localtime = localtime(&current_time);
         infotxt = strdup(message);
-        log_fd = fl_fopen(cfg.main.log_file, "ab");
+        log_fd = fl_fopen(log_file, "ab");
         if (log_fd != NULL) {
             strftime(logtimestamp, sizeof(logtimestamp), "%Y-%m-%d %H:%M:%S", current_localtime);
             if (strchr(infotxt, ':')) {
@@ -1804,7 +1810,7 @@ void update_slider_from_midi(Fl_Slider *slider, int command_id, int value)
     Fl::awake(do_callback_on_main_thread, slider);
 }
 
-int exec_midi_command(int command_id, int value)
+int exec_midi_command(int command_id, int msg_type, int value)
 {
     /*
     printf("command_type: %d\n", command_type);
@@ -1816,48 +1822,97 @@ int exec_midi_command(int command_id, int value)
     Fl::lock();
     switch (command_id) {
     case MIDI_CMD_START_STOP_BROADCASTING:
-        if (value >= 64) {
+        if (msg_type == MIDI_MSG_TYPE_CC) {
+            if (value >= 64) {
+                if (connected == false) {
+                    Fl::awake(connect_on_main_thread, NULL);
+                }
+            }
+            else {
+                if (connected == true) {
+                    Fl::awake(disconnect_on_main_thread, &ask);
+                }
+                else {
+                    try_to_connect = 0;
+                }
+            }
+        }
+        else if (msg_type == MIDI_MSG_TYPE_NOTE_ON) {
             if (connected == false) {
                 Fl::awake(connect_on_main_thread, NULL);
             }
-        }
-        else {
-            if (connected == true) {
-                Fl::awake(disconnect_on_main_thread, &ask);
-            }
             else {
-                try_to_connect = 0;
+                Fl::awake(disconnect_on_main_thread, &ask);
             }
         }
         break;
-
+    case MIDI_CMD_START_BROADCASTING:
+        if (connected == false) {
+            Fl::awake(connect_on_main_thread, NULL);
+        }
+        break;
+    case MIDI_CMD_STOP_BROADCASTING:
+        Fl::awake(disconnect_on_main_thread, &ask);
+        break;
     case MIDI_CMD_START_STOP_RECORDING:
-        if (value >= 64) {
+        if (msg_type == MIDI_MSG_TYPE_CC) {
+            if (value >= 64) {
+                if (recording == false) {
+                    Fl::awake(start_record_on_main_thread, &ask);
+                }
+            }
+            else {
+                Fl::awake(stop_record_on_main_thread, &ask);
+            }
+        }
+        else if (msg_type == MIDI_MSG_TYPE_NOTE_ON) {
             if (recording == false) {
                 Fl::awake(start_record_on_main_thread, &ask);
             }
+            else {
+                Fl::awake(stop_record_on_main_thread, &ask);
+            }
         }
-        else {
+        break;
+    case MIDI_CMD_START_RECORDING:
+        if (recording == false) {
+            Fl::awake(start_record_on_main_thread, &ask);
+        }
+        break;
+    case MIDI_CMD_STOP_RECORDING:
+        if (recording == true) {
             Fl::awake(stop_record_on_main_thread, &ask);
         }
         break;
     case MIDI_CMD_MASTER_GAIN:
-        update_slider_from_midi(fl_g->slider_gain, command_id, value);
+        if (msg_type == MIDI_MSG_TYPE_CC) {
+            update_slider_from_midi(fl_g->slider_gain, command_id, value);
+        }
         break;
     case MIDI_CMD_STREAMING_GAIN:
-        update_slider_from_midi(fl_g->slider_mixer_streaming_gain, command_id, value);
+        if (msg_type == MIDI_MSG_TYPE_CC) {
+            update_slider_from_midi(fl_g->slider_mixer_streaming_gain, command_id, value);
+        }
         break;
     case MIDI_CMD_RECORDING_GAIN:
-        update_slider_from_midi(fl_g->slider_mixer_recording_gain, command_id, value);
+        if (msg_type == MIDI_MSG_TYPE_CC) {
+            update_slider_from_midi(fl_g->slider_mixer_recording_gain, command_id, value);
+        }
         break;
     case MIDI_CMD_PRIMARY_DEV_VOL:
-        update_slider_from_midi(fl_g->slider_mixer_primary_device, command_id, value);
+        if (msg_type == MIDI_MSG_TYPE_CC) {
+            update_slider_from_midi(fl_g->slider_mixer_primary_device, command_id, value);
+        }
         break;
     case MIDI_CMD_SECONDARY_DEV_VOL:
-        update_slider_from_midi(fl_g->slider_mixer_secondary_device, command_id, value);
+        if (msg_type == MIDI_MSG_TYPE_CC) {
+            update_slider_from_midi(fl_g->slider_mixer_secondary_device, command_id, value);
+        }
         break;
     case MIDI_CMD_CROSS_FADER:
-        update_slider_from_midi(fl_g->slider_mixer_cross_fader, command_id, value);
+        if (msg_type == MIDI_MSG_TYPE_CC) {
+            update_slider_from_midi(fl_g->slider_mixer_cross_fader, command_id, value);
+        }
         break;
     case MIDI_CMD_PRIMARY_DEV_MUTE_UNMUTE:
         fl_g->button_mixer_mute_primary_device->value(!fl_g->button_mixer_mute_primary_device->value());
