@@ -17,9 +17,10 @@
 #include <stdlib.h>
 #include <math.h>
 #include "config.h"
-#include "fl_funcs.h"
+#include "FLTK/fl_funcs.h"
 #include "aac_encode.h"
 #include "wav_header.h"
+#include "util.h"
 
 int g_aac_lib_available = 0;
 
@@ -254,14 +255,21 @@ int aac_enc_flush_file(aac_enc *aac, FILE *file)
                 break;
             }
             else {
-                //NOTE: When using the asan profile on macOS the flushing fails
+                // NOTE: When using the asan profile on macOS the flushing fails
                 printf("AAC flushing error: 0x%04X\n", ret);
                 aac->state = AAC_READY;
                 return 1;
             }
         }
 
-        fwrite(enc_buf, sizeof(char), out_args.numOutBytes, file);
+        char *write_error_msg;
+        int ret = safe_fwrite(enc_buf, sizeof(char), out_args.numOutBytes, file, &write_error_msg);
+        if (ret == -1) {
+            char error_msg[1024];
+            snprintf(error_msg, sizeof(error_msg), "Error flushing AAC data: %s", write_error_msg);
+            print_info(error_msg, 1);
+            free(write_error_msg);
+        }
     }
 
     aac->state = AAC_READY;
