@@ -39,6 +39,9 @@ const char *lang_array_old[] = {"system", "de", "en", "fr", "pt_BR"};
 
 config_t cfg;
 char *cfg_path;
+#if !defined(__APPLE__) && !defined(WIN32)
+char *jack_client_name;
+#endif
 
 int cfg_write_file(char *path)
 {
@@ -141,6 +144,7 @@ int cfg_write_file(char *path)
     fprintf(cfg_fd, "signal_detection = %d\n", cfg.main.signal_detection);
     fprintf(cfg_fd, "silence_detection = %d\n", cfg.main.silence_detection);
     fprintf(cfg_fd, "check_for_update = %d\n", cfg.main.check_for_update);
+    fprintf(cfg_fd, "check_for_buttm = %d\n", cfg.main.check_for_buttm);
     fprintf(cfg_fd, "start_agent = %d\n", cfg.main.start_agent);
     fprintf(cfg_fd, "minimize_to_tray = %d\n", cfg.main.minimize_to_tray);
     fprintf(cfg_fd, "connect_at_startup = %d\n", cfg.main.connect_at_startup);
@@ -878,6 +882,7 @@ int cfg_set_values(char *path)
     cfg.main.force_reconnecting = cfg_get_int("main", "force_reconnecting", 0);
     cfg.main.reconnect_delay = cfg_get_int("main", "reconnect_delay", 1);
     cfg.main.check_for_update = cfg_get_int("main", "check_for_update", 1);
+    cfg.main.check_for_buttm = cfg_get_int("main", "check_for_buttm", 1);
     cfg.main.start_agent = cfg_get_int("main", "start_agent", 0);
     cfg.main.minimize_to_tray = cfg_get_int("main", "minimize_to_tray", 0);
 
@@ -1166,6 +1171,7 @@ int cfg_create_default(void)
                     "signal_detection = 0\n"
                     "silence_detection = 0\n"
                     "check_for_update = 1\n"
+                    "check_for_buttm = 1\n"
                     "start_agent = 0\n"
                     "minimize_to_tray = 0\n"
                     "force_reconnecting = 0\n"
