@@ -184,6 +184,7 @@ typedef struct {
         int signal_detection;
         int silence_detection;
         int check_for_update;
+        int check_for_buttm;
         int start_agent;
         int minimize_to_tray;
         float gain;
@@ -392,6 +393,9 @@ typedef struct {
 
 extern char *cfg_path; // Path to config file
 extern config_t cfg;   // Holds config parameters
+#if !defined(__APPLE__) && !defined(WIN32)
+extern char *jack_client_name; // JACK client name
+#endif
 
 int cfg_write_file(char *path); // Writes current config_t struct to path or cfg_path if path is NULL
 int cfg_set_values(char *path); // Reads config file from path or cfg_path if path is NULL and fills the config_t struct
