@@ -238,9 +238,13 @@ int flac_enc_encode_stream(flac_enc *flac, float *pcm_float, uint8_t *enc_buf, i
     samples_left = samples_per_chan;
 
     pcm_int32 = (int32_t *)pcm_float;
+    float sum;
     while (samples_left > 0) {
         // Convert 16bit samples to 32bit samples
+        sum = 0;
         for (i = 0; i < chunk_size * channel; i++) {
+            sum += abs(pcm_float[i + samples_written]);
+
             if (pcm_float[i + samples_written] > 0) {
                 if (flac->bit_depth == 16) {
                     pcm_int32[i] = (int32_t)round(fmin(pcm_float[i + samples_written] * INT16_MAX, INT16_MAX));
@@ -259,6 +263,16 @@ int flac_enc_encode_stream(flac_enc *flac, float *pcm_float, uint8_t *enc_buf, i
             }
         }
 
+        // Add some noise with minimum volume in case the audio data is totaly silent.
+        // This makes sure the FLAC encoder returns encoded data.
+        // Otherwise, if the encoder receives 100 % silence, no encoded audio data
+        // would be send to the streaming server and thus would drop the connection.
+        if (sum == 0) {
+            for (i = 0; i < chunk_size * channel; i++) {
+                pcm_int32[i] = (rand() % 3) - 1;
+            }
+        }
+
         FLAC__stream_encoder_process_interleaved(flac->encoder, pcm_int32, chunk_size);
 
         samples_written += chunk_size * channel;
