@@ -18,7 +18,8 @@
 
 #include "gettext.h"
 #include "lame_encode.h"
-#include "fl_funcs.h"
+#include "FLTK/fl_funcs.h"
+#include "util.h"
 
 int lame_enc_init(lame_enc *lame)
 {
@@ -124,7 +125,14 @@ int lame_enc_flush_file(lame_enc *lame, FILE *file)
     bytes_flushed = lame_encode_flush(lame->gfp, (unsigned char *)buf, sizeof(buf));
 
     if (bytes_flushed > 0) {
-        fwrite(buf, 1, bytes_flushed, file);
+        char *write_error_msg;
+        int ret = safe_fwrite(buf, 1, bytes_flushed, file, &write_error_msg);
+        if (ret == -1) {
+            char error_msg[1024];
+            snprintf(error_msg, sizeof(error_msg), "Error flushing MP3 data: %s", write_error_msg);
+            print_info(error_msg, 1);
+            free(write_error_msg);
+        }
         //    lame_mp3_tags_fid(lame->gfp, file);
         //    lame_init_bitstream(lame->gfp);
     }
