@@ -26,6 +26,10 @@
 #include <windows.h>
 #endif
 
+#if !defined(__APPLE__) && !defined(WIN32)
+#include <pa_jack.h>
+#endif
+
 #include "gettext.h"
 #include "config.h"
 
@@ -126,6 +130,12 @@ int snd_init(void)
 {
     char info_buf[256];
 
+#if !defined(__APPLE__) && !defined(WIN32) // JACK: Set client name before Pa_Initialize
+    if (jack_client_name != NULL && strlen(jack_client_name) > 0) {
+        PaJack_SetClientName(jack_client_name);
+    }
+#endif
+
     PaError p_err;
     if ((p_err = Pa_Initialize()) != paNoError) {
         snprintf(info_buf, sizeof(info_buf), _("PortAudio init failed:\n%s\n"), Pa_GetErrorText(p_err));
@@ -427,9 +437,6 @@ int snd_callback(const void *input, void *output, unsigned long frameCount, cons
 {
     float *pcm_input = (float *)input;
 
-    if (statusFlags != 0) {
-        printf("1 status: %lu\n", statusFlags);
-    }
 
     if (cfg.audio.channel == 1) { // User has selected mono
         for (uint32_t i = 0; i < frameCount; i++) {
@@ -542,9 +549,6 @@ int snd_callback2(const void *input, void *output, unsigned long frameCount, con
                   void *userData)
 {
     float *pcm_input = (float *)input;
-    if (statusFlags != 0) {
-        printf("2 status: %lu\n", statusFlags);
-    }
 
     if (cfg.audio.channel == 1) { // User has selected mono
         for (uint32_t i = 0; i < frameCount; i++) {
@@ -954,14 +958,17 @@ void snd_stop_recording_thread(void)
 // bandwidth is smaller than the selected streaming bitrate
 void *snd_rec_thread(void *data)
 {
+    size_t ret;
     int rb_bytes_read;
     int bytes_to_read;
     int opus_header_written;
     int enc_bytes_read;
     int buf_size = rec_rb.size * sizeof(char) * 10;
+    char error_msg[1024];
 
     char *enc_buf = (char *)malloc(buf_size);
     char *audio_buf = (char *)malloc(buf_size);
+    char *write_error_msg;
 
     opus_header_written = 0;
 
@@ -984,8 +991,12 @@ void *snd_rec_thread(void *data)
             if (!strcmp(cfg.rec.codec, "ogg")) {
                 // Flush encoder
                 enc_bytes_read = vorbis_enc_encode(&vorbis_rec, NULL, enc_buf, 0);
-                printf("flushed %d bytes\n", enc_bytes_read);
-                fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd);
+                ret = safe_fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd, &write_error_msg);
+                if (ret == -1) {
+                    snprintf(error_msg, sizeof(error_msg), "Error writing OGG data: %s", write_error_msg);
+                    print_info(error_msg, 1);
+                    free(write_error_msg);
+                }
                 fclose(cfg.rec.fd);
                 cfg.rec.fd = next_fd;
                 next_file = 0;
@@ -1034,7 +1045,13 @@ void *snd_rec_thread(void *data)
                 }
 
                 enc_bytes_read = opus_enc_encode(&opus_rec, (float *)audio_buf, enc_buf);
-                kbytes_written += fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd) / 1024.0;
+                ret = safe_fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd, &write_error_msg);
+                if (ret == -1) {
+                    snprintf(error_msg, sizeof(error_msg), "Error writing OPUS data: %s", write_error_msg);
+                    print_info(error_msg, 1);
+                    free(write_error_msg);
+                }
+                kbytes_written += ret / 1024.0;
 
                 if (opus_rec.state == OPUS_STATE_NEW_STREAM) {
                     fclose(cfg.rec.fd);
@@ -1043,7 +1060,13 @@ void *snd_rec_thread(void *data)
                     opus_enc_write_header(&opus_rec);
                     opus_header_written = 1;
                     enc_bytes_read = opus_enc_encode(&opus_rec, opus_rec.last_pcm_packet, enc_buf);
-                    kbytes_written += fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd) / 1024.0;
+                    ret = safe_fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd, &write_error_msg);
+                    if (ret == -1) {
+                        snprintf(error_msg, sizeof(error_msg), "Error writing OPUS data to new file: %s", write_error_msg);
+                        print_info(error_msg, 1);
+                        free(write_error_msg);
+                    }
+                    kbytes_written += ret / 1024.0;
                 }
             }
         }
@@ -1054,7 +1077,13 @@ void *snd_rec_thread(void *data)
                 rb_read_len(&rec_rb, audio_buf, bytes_to_read);
 
                 enc_bytes_read = aac_enc_encode(&aac_rec, (float *)audio_buf, enc_buf, bytes_to_read / (cfg.audio.channel * sizeof(float)), buf_size);
-                kbytes_written += fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd) / 1024.0;
+                ret = safe_fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd, &write_error_msg);
+                if (ret == -1) {
+                    snprintf(error_msg, sizeof(error_msg), "Error writing AAC data: %s", write_error_msg);
+                    print_info(error_msg, 1);
+                    free(write_error_msg);
+                }
+                kbytes_written += ret / 1024.0;
             }
         }
 #endif
@@ -1070,7 +1099,13 @@ void *snd_rec_thread(void *data)
 
             if (!strcmp(cfg.rec.codec, "mp3")) {
                 enc_bytes_read = lame_enc_encode(&lame_rec, (float *)audio_buf, enc_buf, rb_bytes_read / (cfg.audio.channel * sizeof(float)), buf_size);
-                kbytes_written += fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd) / 1024.0;
+                ret = safe_fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd, &write_error_msg);
+                if (ret == -1) {
+                    snprintf(error_msg, sizeof(error_msg), "Error writing MP3 data: %s", write_error_msg);
+                    print_info(error_msg, 1);
+                    free(write_error_msg);
+                }
+                kbytes_written += ret / 1024.0;
             }
 
             if (!strcmp(cfg.rec.codec, "ogg")) {
@@ -1079,7 +1114,13 @@ void *snd_rec_thread(void *data)
                 }
 
                 enc_bytes_read = vorbis_enc_encode(&vorbis_rec, (float *)audio_buf, enc_buf, rb_bytes_read / (cfg.audio.channel * sizeof(float)));
-                kbytes_written += fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd) / 1024.0;
+                ret = safe_fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd, &write_error_msg);
+                if (ret == -1) {
+                    snprintf(error_msg, sizeof(error_msg), "Error writing OGG data: %s", write_error_msg);
+                    print_info(error_msg, 1);
+                    free(write_error_msg);
+                }
+                kbytes_written += ret / 1024.0;
             }
 
             if (!strcmp(cfg.rec.codec, "flac")) {
@@ -1130,13 +1171,20 @@ void *snd_rec_thread(void *data)
                     }
                 }
 
-                kbytes_written += fwrite(audio_buf, cfg.wav_codec_rec.bit_depth / 8, rb_bytes_read / sizeof(float), cfg.rec.fd) / 1024.0;
+                ret = safe_fwrite(audio_buf, cfg.wav_codec_rec.bit_depth / 8, rb_bytes_read / sizeof(float), cfg.rec.fd, &write_error_msg);
+                if (ret == -1) {
+                    snprintf(error_msg, sizeof(error_msg), "Error writing WAV data: %s", write_error_msg);
+                    print_info(error_msg, 1);
+                    free(write_error_msg);
+                }
+                kbytes_written += ret / 1024.0;
             }
         }
     }
 
     if (!strcmp(cfg.rec.codec, "wav")) {
         wav_write_header(cfg.rec.fd, cfg.audio.channel, cfg.audio.samplerate, cfg.wav_codec_rec.bit_depth);
+        fclose(cfg.rec.fd);
     }
     else if (!strcmp(cfg.rec.codec, "flac")) { // The flac encoder closes the file
         flac_enc_close_file(&flac_rec);
@@ -1149,7 +1197,12 @@ void *snd_rec_thread(void *data)
     else if (!strcmp(cfg.rec.codec, "ogg")) {
         enc_bytes_read = vorbis_enc_encode(&vorbis_rec, NULL, enc_buf, 0);
         vorbis_enc_reinit(&vorbis_rec);
-        fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd);
+        ret = safe_fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd, &write_error_msg);
+        if (ret == -1) {
+            snprintf(error_msg, sizeof(error_msg), "Error flushing OGG data: %s", write_error_msg);
+            print_info(error_msg, 1);
+            free(write_error_msg);
+        }
         fclose(cfg.rec.fd);
     }
 
