@@ -7,6 +7,7 @@
 #include "url.h"
 
 char new_version[16];
+char BUTTM_text[1024];
 
 int update_check_for_new_version(void)
 {
@@ -48,7 +49,35 @@ int update_check_for_new_version(void)
     return UPDATE_UP_TO_DATE;
 }
 
+int update_check_for_BUTTM(void)
+{
+    int ret;
+    char response[1024];
+
+    memset(BUTTM_text, 0, sizeof(BUTTM_text));
+
+    ret = url_get("http://danielnoethen.de/buttm_available", NULL, response, sizeof(response));
+    if (ret <= 0) {
+        return UPDATE_ILLEGAL_ANSWER;
+    }
+    response[ret] = '\0';
+
+    char *p = strstr(response, "BUTTM:\n");
+    if (p == NULL) {
+        return UPDATE_ILLEGAL_ANSWER;
+    }
+
+    p += strlen("BUTTM:\n");
+
+    snprintf(BUTTM_text, sizeof(BUTTM_text) - 1, "%s", p);
+    return UPDATE_BUTTM_AVAILABLE;
+}
 char *update_get_version(void)
 {
     return new_version;
 }
+
+char *update_get_BUTTM_text(void)
+{
+    return BUTTM_text;
+}
