@@ -15,6 +15,7 @@
 //
 #ifndef UTIL_H
 #define UTIL_H
+#include <stdio.h>
 
 char *util_base64_enc(char *data);
 char *util_get_file_extension(char *filename);
@@ -22,5 +23,6 @@ float util_factor_to_db(float factor);
 float util_db_to_factor(float dB);
 void set_max_thread_priority(void);
 int util_mkpath(char *path);
+size_t safe_fwrite(const void *ptr, size_t size, size_t nmemb, FILE *fp, char **err_msg);
 
 #endif
