@@ -17,8 +17,11 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include "wav_header.h"
+#include "util.h"
+#include "FLTK/fl_funcs.h"
 
 int wav_write_header(FILE *fd, short ch, int srate, short bps)
 {
@@ -51,7 +54,14 @@ int wav_write_header(FILE *fd, short ch, int srate, short bps)
 
     // write header to the beginning of the file
     rewind(fd);
-    fwrite(&hdr.data, 1, sizeof(wav_hdr_t), fd);
+    char *write_error_msg;
+    int ret = safe_fwrite(&hdr.data, 1, sizeof(wav_hdr_t), fd, &write_error_msg);
+    if (ret == -1) {
+        char error_msg[1024];
+        snprintf(error_msg, sizeof(error_msg), "Error writing WAV header: %s", write_error_msg);
+        print_info(error_msg, 1);
+        free(write_error_msg);
+    }
 
     // set the fd back to the fileend
     fseeko(fd, 0, SEEK_END);
